orca_wasm::ir

Module function

Function Builder

Structs

  • Build a function from scratch See an example here.
  • Modify a function Uses same injection logic as Iterator, which is different from FunctionBuilder since FunctionModifier does side effect to operators at encoding (it only modifies the Instrument type)